package tech.powerjob.work.service.impl.waterPassengerTransport;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import tech.powerjob.work.entity.waterPassengerTransport.*;
import tech.powerjob.work.mapper.waterPassengerTransport.HMDataServiceMapper;
import tech.powerjob.work.service.waterPassengerTransport.HMDataShareService;
import tech.powerjob.work.util.ApiUtils;
import tech.powerjob.work.util.DateUtils;
import tech.powerjob.worker.core.processor.ProcessResult;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @ClassName: HMDataServiceImpl
 * @description: TODO
 * @author: sbj
 * @time: 2022/8/20 16:29
 * @Version: 1.0
 */
@Service
@Slf4j
public class HMDataServiceImpl implements HMDataShareService {

    @Value("${preGhjgWebService}")
    private String preGhjgWebService;

    @Autowired
    HMDataServiceMapper mapper;

    @Override
    public ProcessResult getDataHandel() {
        try {
            getDataForEach();
        } catch (Exception e) {
            e.printStackTrace();
            log.info(e.getMessage());
        }
        log.info("执行完毕");
        System.out.println("执行完毕");
        return new ProcessResult(true);
    }

    private void getDataForEach() {
        try {
            String startTime = DateUtils.getNowTimeStringToDD();
            String endTime = DateUtils.getNowTimeStringToDD();
            String token = getToken();
            if (!StringUtils.isBlank(token)) {
                // 航班信息
                getHBInfo(startTime, endTime, token);
                // 统计信息
                getTotalInfo(startTime, token);
                // 营运船方公司信息
                getCompanyInfo(startTime, endTime, token);
                // 客运船舶信息
                getShipInfo(startTime, endTime, token);
                // 航班信息
//            getScheduleInfo(startTime,endTime,token);
                // 日水上旅游客运信息（分航次、航线的客流量）
                getDaylyLYKYInfo(startTime, endTime, token);
                // 日客流售票信息
                getDaylyTicketInfo(startTime, endTime, token);
                // 码头泊位字典表
                getBerthDictInfo(startTime, endTime, token);
                // 航班类型字典表
                getHBDictInfo(startTime, endTime, token);
                //泊位状态接口
                getBerthStatusInfo(token);
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.info(e.getMessage());
        }
    }

    /**
     * {
     * "Success": true,
     * "Message": null,
     * "Data": {
     * "token": "97640ed4-342e-456a-86aa-a152faf60059"
     * }
     * }
     */
    // 获取token
    public String getToken() {
        try {
            Map<String, String> headers = new HashMap();
            String url = preGhjgWebService + "hdsp/CheckToken";  //资源url地址
            log.info("getToken开始调用");
            String result = ApiUtils.post(url, headers, "");   //post请求
            log.info("getToken 返回结果：" + result);
            String token = "";
            if (StringUtils.isBlank(result)) {
                log.info("CheckToken 返回结果为空");
            } else {
                if (result.indexOf("checkToken异常") == -1) {
                    token = result.replace("\r\n", "");
                }
            }
            return token;
        } catch (Exception e) {
            e.printStackTrace();
            log.info(e.getMessage());
            return "";
        }
    }

    private void getHBInfo(String startTime, String endTime, String token) {
        try {
            String method = "Schedule/Query";
            Map<String, String> headers = new HashMap();
            headers.put("method", method);
            headers.put("startTime", startTime);
            headers.put("endTime", endTime);
            String url = preGhjgWebService + "hdsp/GetHMService";  //资源url地址
            String json = "{\"method\":\"" + method + "\",\"startTime\":\"" + startTime + "\",\"endTime\":\"" + endTime + "\",\"token\":\"" + token + "\"}";
            log.info("Schedule/Query开始调用 参数：" + json);
            String result = ApiUtils.post(url, headers, json);   //post请求
            log.info("Schedule/Query 返回结果：" + result);
            if (StringUtils.isBlank(result)) {
                log.info("Schedule/Query 返回结果为空");
            } else {
                JSONObject object = JSONObject.parseObject(result);
                if ((Boolean) object.get("Success")) {
                    List<HmScheduleTicket> list = JSONObject.parseArray(String.valueOf(object.get("Data")), HmScheduleTicket.class);
                    if (list.size() > 0) {
//                        list.sort((o1, o2) -> {
//                            try {
//                                Date date1 = DateUtils.stringToDate(o1.getScheduleTime(), DateUtils.DATE_FORMAT_19);
//                                Date date2 = DateUtils.stringToDate(o2.getScheduleTime(), DateUtils.DATE_FORMAT_19);
//                                return date1.compareTo(date2);
//                            } catch (ParseException e) {
//                                e.printStackTrace();
//                                log.error(e.getMessage());
//                                return 0;
//                            }
//                        });
                        for (HmScheduleTicket item : list) {
                            mapper.SaveOrUpdateScheduleTicket(item);
                        }
                    }
                    log.info("Schedule/Query 执行完毕 数据总数：" + list.size());
                } else {
                    log.info("Schedule/Query:" + object.get("Message").toString());
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.info(e.getMessage());
        }
    }

    private void getTotalInfo(String dayTime, String token) {
        try {
            String method = "Schedule/TotalQuery";
            Map<String, String> headers = new HashMap();
            headers.put("method", method);
            headers.put("dockCode", "");
            headers.put("dayTime", dayTime);
            String url = preGhjgWebService + "hdsp/GetHMService";  //资源url地址
            String json = "{\"method\":\"" + method + "\",\"dockCode\":\"\",\"dayTime\":\"" + dayTime + "\",\"token\":\"" + token + "\"}";
            log.info("Schedule/TotalQuery 参数：" + json);
            String result = ApiUtils.post(url, headers, json);   //post请求
            log.info("Schedule/TotalQuery 返回结果：" + result);
            if (StringUtils.isBlank(result)) {
                log.info("Schedule/TotalQuery 返回结果为空");
            } else {
                JSONObject object = JSONObject.parseObject(result);
                if ((Boolean) object.get("Success")) {
                    HmTotalInfo data = JSONObject.parseObject(String.valueOf(object.get("Data")), HmTotalInfo.class);
                    if (data != null) {
                        data.setDockCode("0");
                        data.setDayTime(dayTime);
                        mapper.SaveOrUpdateTotalInfo(data);
                    }
                    log.info("Schedule/TotalQuery 执行完毕!");
                } else {
                    log.info("Schedule/TotalQuery:" + object.get("Message").toString());
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.info(e.getMessage());
        }
    }

    private void getCompanyInfo(String startTime, String endTime, String token) {
        try {
            String method = "CommonInfo/Company";
            Map<String, String> headers = new HashMap();
            headers.put("method", method);
            String url = preGhjgWebService + "hdsp/GetHMService";  //资源url地址
            String json = "{\"method\":\"" + method + "\",\"token\":\"" + token + "\"}";
            log.info("CommonInfo/Company 参数：" + json);
            String result = ApiUtils.post(url, headers, json);   //post请求
            log.info("CommonInfo/Company 返回结果：" + result);
            if (StringUtils.isBlank(result)) {
                log.info("CommonInfo/Company 返回结果为空");
            } else {
                JSONObject object = JSONObject.parseObject(result);
                if ((Boolean) object.get("Success")) {
                    List<HmCompanyInfo> list = JSONObject.parseArray(String.valueOf(object.get("Data")), HmCompanyInfo.class);
                    if (list.size() > 0) {
                        for (HmCompanyInfo item : list) {
                            mapper.SaveOrUpdateCompany(item);
                        }
                    }
                    log.info("CommonInfo/Company 执行完毕！数据总数：" + list.size());
                } else {
                    log.info("CommonInfo/Company:" + object.get("Message").toString());
                }
            }

        } catch (Exception e) {
            e.printStackTrace();
            log.info(e.getMessage());
        }
    }

    private void getShipInfo(String startTime, String endTime, String token) {
        try {
            String method = "CommonInfo/Ship";
            Map<String, String> headers = new HashMap();
            headers.put("method", method);
            String url = preGhjgWebService + "hdsp/GetHMService";  //资源url地址
            String json = "{\"method\":\"" + method + "\",\"token\":\"" + token + "\"}";
            log.info("CommonInfo/Ship 参数：" + json);
            String result = ApiUtils.post(url, headers, json);   //post请求
            log.info("CommonInfo/Ship 返回结果：" + result);
            if (StringUtils.isBlank(result)) {
                log.info("CommonInfo/Ship 返回结果为空");
            } else {
                JSONObject object = JSONObject.parseObject(result);
                if ((Boolean) object.get("Success")) {
                    List<HmShipInfo> list = JSONObject.parseArray(String.valueOf(object.get("Data")), HmShipInfo.class);
                    if (list.size() > 0) {
                        for (HmShipInfo item : list) {
                            mapper.SaveOrUpdateShipInfo(item);
                        }
                    }
                    log.info("CommonInfo/Ship 执行完毕！数据总数：" + list.size());
                } else {
                    log.info("CommonInfo/Ship:" + object.get("Message").toString());
                }
            }

        } catch (Exception e) {
            e.printStackTrace();
            log.info(e.getMessage());
        }
    }

    private void getScheduleInfo(String startTime, String endTime, String token) {
        try {
            String method = "CommonInfo/Schedule";
            Map<String, String> headers = new HashMap();
            headers.put("method", method);
            headers.put("startTime", startTime);
            headers.put("endTime", endTime);
            String url = preGhjgWebService + "hdsp/GetHMService";  //资源url地址
            String json = "{\"method\":\"" + method + "\",\"startTime\":\"" + startTime + "\",\"endTime\":\"" + endTime + "\",\"token\":\"" + token + "\"}";
            log.info("CommonInfo/Schedule 参数：" + json);
            String result = ApiUtils.post(url, headers, json);   //post请求
            log.info("CommonInfo/Schedule 返回结果：" + result);
            if (StringUtils.isBlank(result)) {
                log.info("CommonInfo/Schedule 返回结果为空");
            } else {
                JSONObject object = JSONObject.parseObject(result);
                if ((Boolean) object.get("Success")) {
                    List<HmScheduleTicket> list = JSONObject.parseArray(String.valueOf(object.get("Data")), HmScheduleTicket.class);
                    if (list.size() > 0) {
                        for (HmScheduleTicket item : list) {
                            mapper.SaveOrUpdateScheduleTicket(item);
                        }
                    }
                    log.info("CommonInfo/Schedule 执行完毕！数据总数：" + list.size());
                } else {
                    log.info("CommonInfo/Schedule:" + object.get("Message").toString());
                }
            }

        } catch (Exception e) {
            e.printStackTrace();
            log.info(e.getMessage());
        }
    }

    public void getDaylyLYKYInfo(String startTime, String endTime, String token) {
        try {
            String method = "CommonInfo/Passenger";
            Map<String, String> headers = new HashMap();
            headers.put("method", method);
            headers.put("startTime", startTime);
            headers.put("endTime", endTime);
            String url = preGhjgWebService + "hdsp/GetHMService";  //资源url地址
            String json = "{\"method\":\"" + method + "\",\"startTime\":\"" + startTime + "\",\"endTime\":\"" + endTime + "\",\"token\":\"" + token + "\"}";
            log.info("CommonInfo/Passenger 参数：" + json);
            String result = ApiUtils.post(url, headers, json);   //post请求
            log.info("CommonInfo/Passenger 返回结果：" + result);
            if (StringUtils.isBlank(result)) {
                log.info("CommonInfo/Passenger 返回结果为空");
            } else {
                JSONObject object = JSONObject.parseObject(result);
                if ((Boolean) object.get("Success")) {
                    List<HmScheduleTicket> list = JSONObject.parseArray(String.valueOf(object.get("Data")), HmScheduleTicket.class);
                    if (list.size() > 0) {
                        for (HmScheduleTicket item : list) {
                            mapper.SaveOrUpdatePassenger(item);
                        }
                    }
                    log.info("CommonInfo/Passenger 执行完毕！数据总数：" + list.size());
                } else {
                    log.info("CommonInfo/Passenger:" + object.get("Message").toString());
                }
            }

        } catch (Exception e) {
            e.printStackTrace();
            log.info(e.getMessage());
        }
    }

    private void getDaylyTicketInfo(String startTime, String endTime, String token) {
        try {
            String method = "CommonInfo/TotalPassenger";
            Map<String, String> headers = new HashMap();
            headers.put("method", method);
            headers.put("startTime", startTime);
            headers.put("endTime", endTime);
            String url = preGhjgWebService + "hdsp/GetHMService";  //资源url地址
            String json = "{\"method\":\"" + method + "\",\"startTime\":\"" + startTime + "\",\"endTime\":\"" + endTime + "\",\"token\":\"" + token + "\"}";
            log.info("CommonInfo/TotalPassenger 参数：" + json);
            String result = ApiUtils.post(url, headers, json);   //post请求
            log.info("CommonInfo/TotalPassenger 返回结果：" + result);
            if (StringUtils.isBlank(result)) {
                log.info("CommonInfo/TotalPassenger 返回结果为空");
            } else {
                JSONObject object = JSONObject.parseObject(result);
                if ((Boolean) object.get("Success")) {
                    JSONArray array = JSONObject.parseArray(String.valueOf(object.get("Data")));
                    if (array.size() > 0) {
                        for (Object item : array) {
                            mapper.SaveOrUpdateTotalPassenger(item);
                        }
                    }
                    log.info("CommonInfo/TotalPassenger 执行完毕！数据总数：" + array.size());
                } else {
                    log.info("CommonInfo/TotalPassenger:" + object.get("Message").toString());
                }
            }

        } catch (Exception e) {
            e.printStackTrace();
            log.info(e.getMessage());
        }
    }

    private void getBerthDictInfo(String startTime, String endTime, String token) {
        try {
            String method = "Schedule/GetPierBerthInfo";
            Map<String, String> headers = new HashMap();
            headers.put("method", method);
            String url = preGhjgWebService + "hdsp/GetHMService";  //资源url地址
            String json = "{\"method\":\"" + method + "\",\"token\":\"" + token + "\"}";
            log.info("Schedule/GetPierBerthInfo 参数：" + json);
            String result = ApiUtils.post(url, headers, json);   //post请求
            log.info("Schedule/GetPierBerthInfo 返回结果：" + result);
            if (StringUtils.isBlank(result)) {
                log.info("Schedule/GetPierBerthInfo 返回结果为空");
            } else {
                JSONObject object = JSONObject.parseObject(result);
                if ((Boolean) object.get("Success")) {
                    List<HmPierBerthInfo> list = JSONObject.parseArray(String.valueOf(object.get("Data")), HmPierBerthInfo.class);
                    if (list.size() > 0) {
                        for (HmPierBerthInfo item : list) {
                            mapper.SaveOrUpdatePierBerthInfo(item);
                        }
                    }
                    log.info("Schedule/GetPierBerthInfo 执行完毕！数据总数：" + list.size());
                } else {
                    log.info("Schedule/GetPierBerthInfo:" + object.get("Message").toString());
                }
            }

        } catch (Exception e) {
            e.printStackTrace();
            log.info(e.getMessage());
        }
    }

    private void getHBDictInfo(String startTime, String endTime, String token) {
        try {
            String method = "Schedule/GetScheduleTypeInfo";
            Map<String, String> headers = new HashMap();
            headers.put("method", method);
            String url = preGhjgWebService + "hdsp/GetHMService";  //资源url地址
            String json = "{\"method\":\"" + method + "\",\"token\":\"" + token + "\"}";
            log.info("Schedule/GetScheduleTypeInfo 参数：" + json);
            String result = ApiUtils.post(url, headers, json);   //post请求
            log.info("Schedule/GetScheduleTypeInfo 返回结果：" + result);
            if (StringUtils.isBlank(result)) {
                log.info("Schedule/GetScheduleTypeInfo 返回结果为空");
            } else {
                JSONObject object = JSONObject.parseObject(result);
                if ((Boolean) object.get("Success")) {
                    List<HmScheduleTypeInfo> list = JSONObject.parseArray(String.valueOf(object.get("Data")), HmScheduleTypeInfo.class);
                    if (list.size() > 0) {
                        for (HmScheduleTypeInfo item : list) {
                            mapper.SaveOrUpdateScheduleType(item);
                        }
                    }
                    log.info("Schedule/GetScheduleTypeInfo 执行完毕！数据总数：" + list.size());
                } else {
                    log.info("Schedule/GetScheduleTypeInfo:" + object.get("Message").toString());
                }
            }

        } catch (Exception e) {
            e.printStackTrace();
            log.info(e.getMessage());
        }

    }

    private void getBerthStatusInfo(String token) {
        try {
            String method = "CommonInfo/BerthStatus";
            Map<String, String> headers = new HashMap();
            headers.put("method", method);
            String url = preGhjgWebService + "hdsp/GetHMService";  //资源url地址
            String json = "{\"method\":\"" + method + "\",\"token\":\"" + token + "\"}";
            log.info("CommonInfo/BerthStatus 参数：" + json);
            String result = ApiUtils.post(url, headers, json);   //post请求
            log.info("CommonInfo/BerthStatus 返回结果：" + result);
            if (StringUtils.isBlank(result)) {
                log.info("CommonInfo/BerthStatus 返回结果为空");
            } else {
                JSONObject jsonObject = JSONObject.parseObject(result);
                if ((Boolean) jsonObject.get("Success")) {
                    List<HmScheduleBerthStatus> list = JSONObject.parseArray(String.valueOf(jsonObject.get("Data")), HmScheduleBerthStatus.class);
                    if (list != null && list.size() > 0) {
                        for (HmScheduleBerthStatus hmScheduleBerthStatus : list) {
                            mapper.SaveOrUpdateBerthStatus(hmScheduleBerthStatus);
                        }
                    }
                    log.info("Schedule/GetScheduleTypeInfo 执行完毕！数据总数：" + list.size());
                } else {
                    log.info("Schedule/GetScheduleTypeInfo:" + jsonObject.get("Message").toString());
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.info(e.getMessage());
        }
    }
}
